@@ -74,6 +74,6 @@ def Serve(servicer):
 
     def signal_handler(sig, frame):
         server.stop(0)
-    signal.signal(signal.CTRL_C_EVENT, signal_handler)
+    signal.signal(signal.SIGINT, signal_handler)
     while True:
         pass
\ No newline at end of file
